Test case names should follow proper capitalization conventions. However, some test
names like "3rd party API" are intentionally formatted this way for domain-specific
reasons. If the capitalization is clearly intentional and meaningful, add
`# robocop:off=not-capitalized-test-case-title` comment to the test case.
Otherwise, capitalize the first letter of each word.
